@@ -1,6 +1,6 @@
 from monty.serialization import loadfn
-d=loadfn('/home/kamalch/anaconda3/envs/cgcnn/lib/python3.6/site-packages/pymatgen/core/periodic_table.json')
-dd=loadfn('Elementsold.json')
+d=loadfn('periodic_table.json')
+dd=loadfn('Elements.json')
 allkeys=dd['Pr'].keys()
 gg=dd
 
@@ -20,7 +20,7 @@ for i in no_there:
        if d[i][k]=='no data':
          d[i][k]=-9999
     gg[i]['Z']=d[i]['Atomic no']
-    gg[i]['atom_mass']=d[i]['Atomic mass']
+    gg[i]['atom_mas']=d[i]['Atomic mass']
     gg[i]['atom_rad']=d[i]['Atomic radius calculated']
     gg[i]['X']=d[i]['X']
 
@@ -30,7 +30,6 @@ f=open('Elements_new.json','w')
 f.write(json.dumps(gg))
 f.close()
 
-print (len(gg['Eu'].keys()))
-print (len(gg['P'].keys()))
+
 
 
